summaryrefslogtreecommitdiff
path: root/lisp
diff options
context:
space:
mode:
authorKarl Heuer <kwzh@gnu.org>1997-05-29 17:56:52 +0000
committerKarl Heuer <kwzh@gnu.org>1997-05-29 17:56:52 +0000
commitc8d05b030b6952ef458ec7bb2438059d9ac5ddf0 (patch)
tree703f3a581ea646c79164cad23f325dfe4b91ef46 /lisp
parent9149d738488f681797713bc6a635762519468391 (diff)
downloademacs-c8d05b030b6952ef458ec7bb2438059d9ac5ddf0.tar.gz
(follow-submit-feedback, follow-mode): Doc fix.
(follow-generic-filter): Don't restore the original buffer if it's dead, or if the filter explicitly selected a new buffer.
Diffstat (limited to 'lisp')
-rw-r--r--lisp/follow.el20
1 files changed, 12 insertions, 8 deletions
diff --git a/lisp/follow.el b/lisp/follow.el
index 80f143fba72..f23504da36e 100644
--- a/lisp/follow.el
+++ b/lisp/follow.el
@@ -5,9 +5,9 @@
;; Author: Anders Lindgren <andersl@csd.uu.se>
;; Maintainer: Anders Lindgren <andersl@csd.uu.se>
;; Created: 25 May 1995
-;; Version: 1.6
+;; Version: 1.7
;; Keywords: display, window, minor-mode
-;; Date: 20 Feb 1996
+;; Date: 27 May 1997
;; This file is part of GNU Emacs.
@@ -49,7 +49,7 @@
;; side-by-side window are used. The user can, with the help of Follow
;; mode, use two full-height windows as though they would have been
;; one. Imagine yourself editing a large function, or section of text,
;; and beeing able to use 144 lines instead of the normal 72... (your
;; mileage may vary).
;; The latest version, and a demonstration, are avaiable at:
@@ -467,7 +467,7 @@ Used by `follow-window-size-change'.")
(eval-when-compile (require 'reporter))
(defun follow-submit-feedback ()
- "Sumbit feedback on Follow mode to the author: andersl@csd.uu.se"
+ "Submit feedback on Follow mode to the author: andersl@csd.uu.se"
(interactive)
(require 'reporter)
(and (y-or-n-p "Do you really want to submit a report on Follow mode? ")
@@ -729,7 +729,7 @@ Follow mode comes to its prime when used on a large screen and two
side-by-side window are used. The user can, with the help of Follow
mode, use two full-height windows as though they would have been
one. Imagine yourself editing a large function, or section of text,
-and beeing able to use 144 lines instead of the normal 72... (your
+and being able to use 144 lines instead of the normal 72... (your
mileage may vary).
To split one large window into two side-by-side windows, the commands
@@ -2206,7 +2206,11 @@ report this using the `follow-submit-feedback' function."
;; return to the original window.
(if return-to-orig-win
(select-window orig-win))
- (set-buffer old-buffer))
+ ;; Restore the orignal buffer, unless the filter explicitly
+ ;; changed buffer or killed the old buffer.
+ (if (and (eq buf (current-buffer))
+ (buffer-name old-buffer))
+ (set-buffer old-buffer)))
(follow-invalidate-cache)
@@ -2340,8 +2344,8 @@ report this using the `follow-submit-feedback' function."
;;; called from other places, e.g. `post-command-hook' and
;;; `post-command-idle-hook'.
;; If this function is called it is to late for this window, but
;; we might save other windows from beeing recentered.
(if (and follow-avoid-tail-recenter-p (boundp 'window-scroll-functions))
(add-hook 'window-scroll-functions 'follow-avoid-tail-recenter t))
@@ -49,7 +49,7 @@
;; mode, use two full-height windows as though they would have been
;; one. Imagine yourself editing a large function, or section of text,
-;; and beeing able to use 144 lines instead of the normal 72... (your
+;; and being able to use 144 lines instead of the normal 72... (your
;; mileage may vary).
;; The latest version, and a demonstration, are avaiable at:
@@ -2340,8 +2344,8 @@ report this using the `follow-submit-feedback' function."
;;; called from other places, e.g. `post-command-hook' and
;;; `post-command-idle-hook'.
-;; If this function is called it is to late for this window, but
-;; we might save other windows from beeing recentered.
+;; If this function is called it is too late for this window, but
+;; we might save other windows from being recentered.
(if (and follow-avoid-tail-recenter-p (boundp 'window-scroll-functions))
(add-hook 'window-scroll-functions 'follow-avoid-tail-recenter t))